@@ -4,8 +4,8 @@ from npstructures.raggedshape import RaggedView
 from npstructures import RaggedArray, ragged_slice
 
 from ..datatypes import Bed6, BamEntry
-from ..cigar import count_reference_length, split_cigar
-from ..encoded_array import as_encoded_array, EncodedArray, EncodedRaggedArray
+from ..alignments.cigar import count_reference_length, split_cigar
+from ..encoded_array import EncodedArray, EncodedRaggedArray, as_encoded_array
 from ..encodings import BaseEncoding
 from ..encodings.alphabet_encoding import BamEncoding
 from .file_buffers import FileBuffer
@@ -88,11 +88,11 @@ class BamBuffer(FileBuffer):
         n_cigar_bytes = n_cigar_op*4
         read_names = ragged_slice(self._data, self._new_lines+36, self._new_lines+36+l_read_name-1)
         read_names = EncodedRaggedArray(
-            EncodedArray(read_names.ravel()), read_names.shape)
+            EncodedArray(read_names.ravel(), BaseEncoding), read_names.shape)
         cigars = ragged_slice(self._data, self._new_lines+36+l_read_name,
                               self._new_lines+36+l_read_name+n_cigar_bytes)
 
-        cigars = RaggedArray(cigars.ravel().view(np.uint32), cigars.shape.lengths//4)
+        cigars = RaggedArray(cigars.ravel().view(np.uint32), cigars.lengths//4)
         cigar_cymbol, cigar_length = split_cigar(cigars)
         sequences = ragged_slice(self._data, self._new_lines+36+l_read_name+n_cigar_bytes,
                                  self._new_lines+36+l_read_name+n_cigar_bytes+n_seq_bytes)
@@ -101,7 +101,7 @@ class BamBuffer(FileBuffer):
             BamEncoding)
         
         new_sequences = EncodedRaggedArray(sequences, n_seq_bytes*2)
-        view = RaggedView(new_sequences.shape.starts, l_seq)
+        view = RaggedView(new_sequences._shape.starts, l_seq)
         new_sequences = new_sequences[view]
         quals = ragged_slice(self._data, self._new_lines+36+l_read_name+n_cigar_bytes+n_seq_bytes,
                              self._new_lines+36+l_read_name+n_cigar_bytes+n_seq_bytes+l_seq)# +33
@@ -127,7 +127,7 @@ class BamIntervalBuffer(BamBuffer):
         cigars = self._move_intervals_to_ragged_array(self._new_lines+36+l_read_name,
                                                       self._new_lines+36+l_read_name+n_cigar_bytes, as_sequence=False)
 
-        cigars = RaggedArray(cigars.ravel().view(np.uint32), cigars.shape.lengths//4)
+        cigars = RaggedArray(cigars.ravel().view(np.uint32), cigars.lengths//4)
         cigar_cymbol, cigar_length = split_cigar(cigars)
 
         strand = flag & np.uint16(16)
